Class: Harvest::Client

Inherits:
BaseModel show all
Includes:
HappyMapper
Defined in:
lib/harvest/client.rb

Overview

The model that contains information about a client

Fields

[+id+] (READONLY) the id of the client [+name+] (REQUIRED) the name of the client [+details+] the details of the client [+currency+] what type of currency is associated with the client [+currency_symbol+] what currency symbol is associated with the client [+active?+] true|false on whether the client is active [+highrise_id+] (READONLY) the highrise id associated with this client [+update_at+] (READONLY) the last modification timestamp

Method Summary

Methods inherited from BaseModel

#==, api_path, #attributes=, #initialize, #to_i, #to_xml

Constructor Details

This class inherits a constructor from Harvest::BaseModel