Class: Harvest::Task

Inherits:
BaseModel show all
Includes:
HappyMapper
Defined in:
lib/harvest/task.rb

Overview

The model that contains information about a task

Fields

[+id+] (READONLY) the id of the task [+name+] (REQUIRED) the name of the task [+billable+] whether the task is billable by default [+deactivated+] whether the task is deactivated [+hourly_rate+] what the default hourly rate for the task is [+default?+] whether to add this task to new projects by default

Instance Method Summary collapse

Methods inherited from BaseModel

#==, api_path, #attributes=, #initialize, #to_i, #to_xml

Constructor Details

This class inherits a constructor from Harvest::BaseModel

Instance Method Details

#active?Boolean

Returns:

  • (Boolean)


24
25
26
# File 'lib/harvest/task.rb', line 24

def active?
  !deactivated
end